California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
DAHLE, BRIAN SWARTZ, PAMELA D.
| STATE SENATE 03
DODD, BILL SANTAMARIA, CARLOS J.
STATE SENATE 05
EGGMAN, SUSAN RIDENOUR, JAMES E.
| STATE SENATE 07
GLAZER, STEVEN MOBLEY, JULIE
STATE SENATE 09
DLUZAK, JAMIE SKINNER, NANCY
| STATE SENATE 11
FIELDER, JACQUELINE F WIENER, SCOTT D.
STATE SENATE 13
BECKER, JOSH GLEW, ALEXANDER
| STATE SENATE 15
CORTESE, DAVID DOMINIC RAVEL, ANN
STATE SENATE 17
LAIRD, JOHN S. NOHRDEN, VICKI L.
| STATE SENATE 19
LIMON, S. MONIQUE MICHAELS, GARY J.
STATE SENATE 21
MUELLER, KIPP WILK, SCOTT T.
| STATE SENATE 23
BOGH, ROSILICIE OCHOA MEDINA, ABIGAIL M.
STATE SENATE 25
HAZELTON, KATHLEEN PORTANTINO, ANTHONY
| STATE SENATE 27
SALEM, HOUMAN STERN, HENRY
STATE SENATE 29
CHANG, LING LING NEWMAN, JOSH B.
| STATE SENATE 31
ROTH, RICHARD D. TAYLOR, ROD D.
STATE SENATE 33
CASTILLO, ELIZABETH C. GONZALEZ, LENA
| STATE SENATE 35
BRADFORD, STEVEN PERRY, ANTHONY
STATE SENATE 37
MIN, DAVE MOORLACH, JOHN M.W.
| STATE SENATE 39
ATKINS, TONI G. BLANKENSHIP, LINDA DEALY
ASSEMBLY DISTRICTS
ASSEMBLY 01
BETANCOURT, ELIZABETH DAHLE, MEGAN
| ASSEMBLY 02
SVOLOS, CHARLOTTE WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES HENSON, JAMES R.
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA NELSON, MATTHEW
ASSEMBLY 05
BIGELOW, FRANK
| ASSEMBLY 06
KILEY, KEVIN SMITH, JACKIE
ASSEMBLY 07
JUST, JAMES O. MC CARTY, KEVIN
| ASSEMBLY 08
COOK, CATHERINE M. COOLEY, KEN
ASSEMBLY 09
COOPER, JIM RIGARD, ERIC
| ASSEMBLY 10
JACOBI, VERONICA S. LEVINE, MARC
ASSEMBLY 11
FRAZIER, JR., JAMES L SCHWAB, DEBRA S.
| ASSEMBLY 12
AKINJO, PAUL FLORA, HEATH
ASSEMBLY 13
MILLER, KATHY VILLAPUDUA, CARLOS
| ASSEMBLY 14
GRAYSON, TIM PROCTOR, JANELL ELIZABETH
ASSEMBLY 15
BRINK, SARA V. WICKS, BUFFY
| ASSEMBLY 16
BAUER-KAHAN, REBECCA RUBAY, JOSEPH A.
ASSEMBLY 17
CHIU, DAVID STARCHILD
| ASSEMBLY 18
BONTA, ROB SLAUSON, STEVE
ASSEMBLY 19
MC DONNELL, JOHN P. TING, PHIL
| ASSEMBLY 20
QUIRK, BILL VILLALOBOS, ALEXIS
ASSEMBLY 21
CAMPOS, JOEL GUTIERREZ GRAY, ADAM C.
| ASSEMBLY 22
GILHAM, MARK MULLIN, KEVIN C.
ASSEMBLY 23
PATTERSON, JIM
| ASSEMBLY 24
BERMAN, MARC OHTAKI, PETER I.
ASSEMBLY 25
BRUNTON, ROBERT L. LEE, ALEX T.
| ASSEMBLY 26
MATHIS, DEVON J. PHELPS, ANDREW
ASSEMBLY 27
KALRA, ASH LANCASTER, G. BURT
| ASSEMBLY 28
CRUZ, CARLOS R. LOW, EVAN
ASSEMBLY 29
BANERJEE, SHOMIR STONE, MARK
| ASSEMBLY 30
RIVAS, ROBERT SWETT, GREGORY G.
ASSEMBLY 31
ARAMBULA, JOAQUIN BANUELOS, FERNANDO
| ASSEMBLY 32
COTTA, TODD SALAS JR., RUDY
ASSEMBLY 33
HERRICK, RICK SMITH, THURSTON
| ASSEMBLY 34
FONG, VINCENT SOLIS, JULIE
ASSEMBLY 35
ADDIS, DAWN CUNNINGHAM, JORDAN
| ASSEMBLY 36
FOX, STEVE LACKEY, THOMAS W.
ASSEMBLY 37
BENNETT, STEPHEN A. COLE, CHARLES W.
| ASSEMBLY 38
VALLADARES, SUZETTE M. VOLOTZKY, LUCIE
ASSEMBLY 39
BENITEZ, RICARDO RIVAS, LUZ
| ASSEMBLY 40
RAMOS, JAMES TULLIUS, JENNIFER
ASSEMBLY 41
HOLDEN, CHRIS HVIDSTON, ROBIN A.
| ASSEMBLY 42
KOTYUK, ANDREW F. MAYES, CHAD
ASSEMBLY 43
FRIEDMAN, LAURA GRAVES, MICHAEL A.
| ASSEMBLY 44
IRWIN, JACQUI V. PEDROW, DENISE E.
ASSEMBLY 45
GABRIEL, JESSE GIRGENTI, JEFFI
| ASSEMBLY 46
MURPHY, LANIRA K. NAZARIAN, ADRIN
ASSEMBLY 47
GORDON, MATTHEW REYES, ELOISE GOMEZ
| ASSEMBLY 48
RUBIO, BLANCA
ASSEMBLY 49
BRINK, BURTON CHAU, ED
| ASSEMBLY 50
BLOOM, RICHARD HESS, WILL
ASSEMBLY 51
CARRILLO, WENDY
| ASSEMBLY 52
HOLLE, TONI M. RODRIGUEZ, FREDDIE
ASSEMBLY 53
PLATA, GODFREY SANTIAGO, MIGUEL
| ASSEMBLY 54
JONES, TRACY B. KAMLAGER, SYDNEY
ASSEMBLY 55
CHEN, PHILLIP RODRIGUEZ, ANDREW E
| ASSEMBLY 56
FIGUEROA, AMERICA L. GARCIA, EDUARDO
ASSEMBLY 57
CALDERON, LISA MARTINEZ, JESSICA
| ASSEMBLY 58
GARCIA, CRISTINA VILLA, MARGARET
ASSEMBLY 59
JONES-SAWYER SR., REGINALD BYRON MARTINEZ, EFREN
| ASSEMBLY 60
CERVANTES, SABRINA RAAHAUGE, CHISTOPHER B.
ASSEMBLY 61
MAZAREI, ALI MEDINA, JOSE J.
| ASSEMBLY 62
BURKE, AUTUMN STEELE, ROBERT A.
ASSEMBLY 63
ESTRADA, MARIA RENDON, ANTHONY
| ASSEMBLY 64
GIPSON, MIKE IQBAL-ZUBAIR, FATIMA S.
ASSEMBLY 65
QUIRK-SILVA, SHARON THACKER, CYNTHIA
| ASSEMBLY 66
MURATSUCHI, AL SCHAPER, ARTHUR C.
ASSEMBLY 67
CARLOS, JERRY M. SEYARTO, KELLY
| ASSEMBLY 68
CHOI, STEVEN FOX, MELISSA
ASSEMBLY 69
DALY, TOM WHITE, JON PAUL
| ASSEMBLY 70
O'DONNELL, PATRICK THOMAS, DAVID W.
ASSEMBLY 71
LAVERTU, ELIZABETH L. VOEPEL, RANDY G.
| ASSEMBLY 72
NGUYEN, DIEDRE THU-HA NGUYEN, JANET
ASSEMBLY 73
DAVIES, LAURIE A. RHINEHART, SCOTT
| ASSEMBLY 74
DIXON, DIANE PETRIE-NORRIS, COTTIE
ASSEMBLY 75
SCHWARTZ, KAREN ("KATE") WALDRON, MARIE
| ASSEMBLY 76
BOERNER HORVATH, TASHA BURKHOLDER, MELANIE G.
ASSEMBLY 77
CUTTER, JUNE YANG MAIENSCHEIN, BRIAN
| ASSEMBLY 78
DAVIS, SARAH K. WARD, CHRISTOPHER M.
ASSEMBLY 79
MOORE, JOHN S. WEBER, SHIRLEY
| ASSEMBLY 80
GONZALEZ, LORENA S. VOGEL, JOHN